@@ -29,25 +29,41 @@ class DocTree():
         # create empty tree to fill
         value = {}
         confidence={}
-        
+        coord = {}
+
         # fill in tree starting with roots (those with no parent)
-        self.__export(root, value, istext=True)
-        self.__export(root, confidence, istext=False)
-        
+        self.__export(root, value, value_type='text')
+        self.__export(root, confidence, value_type='confidence')
+        self.__export(root, coord, value_type='coord')
+
         rs = {
                 'value':value, 
-                'confidence':confidence
+                'confidence':confidence,
+                'coord':coord
              }
 
         return rs
     
-    def __export(self, root, container, istext):
+    def get_value(self, child, value_type):
+        if value_type == 'text':
+            value = child.text
+        elif value_type == 'confidence':
+            value = float(child.prob)
+        elif value_type == 'coord':
+            value = (child.x, child.y, child.w, child.h)
+        
+        return value
+
+    def __export(self, root, container, value_type):
+        if value_type not in ['text', 'confidence', 'coord']:
+            raise ValueError('value_type: {} is not supported'.format(value_type))
+
         children = sorted(root.children, key=lambda child: child.y)
 
         for child in children:
             key = child.name
             if child.is_leaf:
-                value = child.text if istext else float(child.prob)
+                value = self.get_value(child, value_type)
                 if key in self.duplicatable_fields:
                     container[key] = container.get(key, [])
                     container[key].append(value)
@@ -60,7 +76,7 @@ class DocTree():
                     container[key].append(next_container)
                 else:
                     container[key] = next_container
-                self.__export(child, next_container, istext)
+                self.__export(child, next_container, value_type)
 
     def merge(self, node):
         children = sorted(node.children, key=lambda child: child.y)
